==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/locale/it/global-error.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$Errors = "Errori";

////////////////////////////////////////////////////////////
// Top level scripts
////////////////////////////////////////////////////////////

$login_failed = "Login fallito, riprova";

////////////////////////////////////////////////////////////
// signup, contact us
////////////////////////////////////////////////////////////

$the_username = "La Username";
$already_exists = " &egrave; gi&agrave; in uso";

$empty_username = "Non &egrave; stata specificata la Username";
$username_too_long = "Username troppo lunga: " . $SESSION["username_length"] . " caratteri max";
$username_too_short = "Username troppo corta: " . $SESSION["username_length_min"] . " caratteri min";
$not_valid_username = "Username non valida: usare solo caratteri alfanumerici";

$passwords_do_not_match = "Le password fornite non coincidono";
$empty_password = "Non &egrave; stata specificata la Password";
$please_enable_javascript =
"<b>
Per motivi di sicurezza, per poter acquistare nel nostro negozio virtuale
&egrave; necessario usare JavaScript.
<p>
Il linguaggio JavaScript, oltre a offrire funzionalit&agrave;
molto utili nella realizzazione di software per il Web,
permette di criptare le password e, quindi, di offrire molta sicurezza
in pi&ugrave; a chi fa uso di questo negozio virtuale.
<p>
Perci&ograve; per acquistare nel nostro negozio virtuale &egrave; necessario
un navigatore che supporti JavaScript, come ad esempio Mozilla, Netscape o Explorer.
Se si sta usando un navigatore che supporta JavaScript ma tale supporto
&egrave; stato disabilitato, si prega di modificare le impostazioni
in modo da abilitare JavaScript.
<p>
Nota: le impostazioni di default di Mozilla, Netscape ed Explorer
prevedono l'uso di JavaScript.
</b><br><br>";

$empty_firstname = "Non &egrave; stato specificato il Nome";
$firstname_too_long = "Nome troppo lungo: " . $SESSION["firstname_length"] . " caratteri max";

$empty_ragionesociale = "Non &egrave; stata specificata la Ragione Sociale";
$ragionesociale_too_long = "Ragione Sociale troppo lunga: " . $SESSION["firstname_length"] . " caratteri max";

$empty_lastname = "Non &egrave; stato specificato il Cognome";
$lastname_too_long = "Cognome troppo lungo: " . $SESSION["lastname_length"] . " caratteri max";

$empty_name = "Non &egrave; stato specificato il Nome";
$name_too_long = "Nome troppo lungo: " . $SESSION["name_length"] . " caratteri max";

$empty_fiscalcode = "Non &egrave; stato specificato il Codice Fiscale";
$bad_fiscalcode_length = "Il Codice Fiscale deve contenere " . $SESSION["fiscalcode_length"] . " caratteri alfanumerici";
$not_valid_fiscalcode = "Codice Fiscale non valido";

$empty_partitaiva = "Non &egrave; stata specificata la Partita IVA";
$bad_partitaiva_length = "La Partita IVA deve contenere " . $SESSION["partitaiva_length"] . " cifre";
$not_valid_partitaiva = "Partita IVA non valida";

$empty_address = "Non &egrave; stato specificato l'indirizzo";
$address_too_long = "Via/Piazza troppo lunga: " . $SESSION["address_length"] . " caratteri max";

$number_too_long = "Numero troppo lungo: " . $SESSION["number_length"] . " caratteri max";

$empty_city = "Non &egrave; stato specificato il comune";
$city_too_long = "Comune troppo lungo: " . $SESSION["city_length"] . " caratteri max";

$empty_country = "Non &egrave; stata specificata la citt&agrave;";
$country_too_long = "Citt&agrave; troppo lunga: " . $SESSION["country_length"] . " caratteri max";

$empty_zip_code = "Riempire il campo del CAP";
$zip_code_is_zero = "Il CAP deve essere maggiore di zero";
$zip_code_notint = "Il campo del CAP deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$zip_code_length_is_wrong = "Il CAP deve contenere esattamente " . $SESSION["zip_code_length"] . " cifre";

$empty_phone = "Non &egrave; stato specificato il numero di telefono";
$phone_too_long = "Numero di telefono troppo lungo: " . $SESSION["phone_length"] . " caratteri max";
$phone_too_short = "Numero di telefono troppo corto: " . $SESSION["phone_length_min"] . " caratteri min";
$not_valid_phone = "Numero di telefono non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$fax_too_long = "Numero di fax troppo lungo: " . $SESSION["fax_length"] . " caratteri max";
$fax_too_short = "Numero di fax troppo corto: " . $SESSION["fax_length_min"] . " caratteri min";
$not_valid_fax = "Numero di fax non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$mobilephone_too_long = "Numero di cellulare troppo lungo: " . $SESSION["mobilephone_length"] . " caratteri max";
$mobilephone_too_short = "Numero di cellulare troppo corto: " . $SESSION["mobilephone_length_min"] . " caratteri min";
$not_valid_mobilephone = "Numero di cellulare non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$empty_email = "Non &egrave; stato specificato l'indirizzo e-mail";
$email_too_long = "Indirizzo e-mail troppo lungo: " . $SESSION["email_length"] . " caratteri max";
$not_valid_email = "Indirizzo E-mail non valido";
//$the_email_address = "L'indirizzo E-mail";
//$email_not_on_file = "L'indirizzo E-mail specificato non ci risulta noto";

$notes_too_long = "Annotazioni troppo lunghe: " . $SESSION["notes_length"] . " caratteri max";
$ournotes_too_long = "Annotazioni troppo lunghe nel campo \"" . $Our_Notes . "\": " . $SESSION["ournotes_length"] . " caratteri max";
$empty_message = "Non &egrave; stato scritto nessun Messaggio";
$message_too_long = "Messaggio troppo lungo: " . $SESSION["message_length"] . " caratteri max";

////////////////////////////////////////////////////////////
// purchase now
////////////////////////////////////////////////////////////

$empty_customer = "Non &egrave; stato specificato il Cliente";
$appoggio = $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1;
$customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri max";
$empty_contact = "Non &egrave; stato specificato un recapito telefonico";
$contact_too_long = "Recapito telefonico troppo lungo: " . $SESSION["phone_length"] . " caratteri max";
$contact_too_short = "Recapito telefonico troppo corto: " . $SESSION["phone_length_min"] . " caratteri min";
$not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
$comments_too_long = "Commenti troppo lunghi: " . $SESSION["comments_length"] . " caratteri max";

////////////////////////////////////////////////////////////
// change password
////////////////////////////////////////////////////////////

$no_old_password = "Non &egrave; stata specificata la vecchia password";
$old_password_not_valid = "La vecchia password &egrave; sbagliata";
$no_new_password = "Non &egrave; stata specificata la nuova password";
$no_new_password2 = "Non &egrave; stata confermata la nuova password";
$new_passwords_dont_match = "Le nuove password non coincidono";

////////////////////////////////////////////////////////////
// add and update category
////////////////////////////////////////////////////////////

$empty_category_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$category_name_too_long = "Il nome della categoria &egrave; troppo lungo: " . $SESSION["category_name_length"] . " caratteri max";
$category_description_too_long = "La descrizione della categoria &egrave; troppo lunga: " . $SESSION["category_description_length"] . " caratteri max";

$priv_too_long = "Privilegio troppo lungo: " . $SESSION["priv_length"] . " caratteri max";
$not_valid_priv = "Privilegio non valido: usare solo caratteri alfanumerici";

$Err_ImpCat = ": la Categoria Padre non esiste - '";

////////////////////////////////////////////////////////////
// add and update brand
////////////////////////////////////////////////////////////

$empty_brand_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$brand_name_too_long = "Il nome della marca &egrave; troppo lungo: " . $SESSION["brand_name_length"] . " caratteri max";
$brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: " . $SESSION["brand_description_length"] . " caratteri max";

$Err_ImpBrand = ": La Marca non esiste - '";
$Err_ImpIVA = ": La " . $IVA . " non esiste - '";

////////////////////////////////////////////////////////////
// add and update product
////////////////////////////////////////////////////////////

$product_code_is_empty = "Riempire il campo del Codice del prodotto";
$product_code_wspace = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene almeno uno spazio. Si prega di non usare spazi nei Codici dei prodotti.";
$product_code_wampersand = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene il carattere \"&amp;\". Si prega di non usarlo nei Codici dei prodotti.";
$product_code_wquestionm = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene il carattere \"?\". Si prega di non usarlo nei Codici dei prodotti.";
$product_code_too_long = "Il Codice del prodotto &egrave; troppo lungo: " . $SESSION["product_code_length"] . " caratteri max";
$the_product_code = "Il Codice ";

$empty_product_name = "Riempire il campo del Nome del prodotto";
$product_name_too_long = "Il nome del prodotto &egrave; troppo lungo: " . $SESSION["product_name_length"] . " caratteri max";

$empty_price = "Riempire il campo del prezzo";
$price_is_zero = "Il Prezzo deve essere maggiore di zero";
$price_notint = "Il campo del Prezzo deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$price_notfloat = "Il campo del Prezzo deve contenere un numero decimale, quindi solo cifre e al pi&ugrave; un punto decimale, nessun altro carattere";

$not_valid_iva = "Valore della " . $IVA . " non valido";
$iva_not_between_0_and_100 = "La " . $IVA . " non &egrave; compresa tra 0 e 100";

$discount_not_completely_defined = "Se si vuole fare sconti sul prodotto, bisogna riempire sia il campo \"" . $Discount . "\" che il campo \"" . $Starting_from . "\"; se non si vuole fare sconti sul prodotto, lasciare vuoti entrambi i campi";
$not_valid_discount = "Sconto non valido";
$discount_not_between_0_and_100 = "Lo Sconto non &egrave; compreso tra 0 e 100";
$discqty_notint = "Il campo \"" . $Starting_from . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$discqty_is_negative = "Il campo \"" . $Starting_from . "\" non pu&ograve; essere un numero negativo";
$discqty_is_too_large = "Il campo \"" . $Starting_from . "\" &egrave; troppo grande: " . $SESSION["discqtymax"] . " max";

$empty_weight = "Riempire il campo del Peso";
$not_valid_weight = "Peso non valido";
$weight_is_zero = "Il Peso deve essere maggiore di zero";
$weight_over_max = "Peso eccessivo: " . $SESSION["weightmax"] . " " . $weightunity . " max";

$special_level_empty = "Riempire il campo \"" . $Special_Level . "\"";
$special_level_notint = "Il campo \"" . $Special_Level . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";

$product_description_too_long = "La descrizione del prodotto &egrave; troppo lunga: " . $SESSION["product_description_length"] . " caratteri max";
$product_extended_description_too_long = "La descrizione estesa del prodotto &egrave; troppo lunga: " . $SESSION["product_extended_description_length"] . " caratteri max";

$appoggio = floor ($SESSION["max_file_size_images"] / 1024);
$no_product_image_chosen = "Non &egrave; stata scelta una nuova immagine per rappresentare il prodotto, oppure l'immagine scelta &egrave; troppo grande: " . $appoggio . " bytes max";
$image_upload_failed = "Upload dell'immagine fallito";
$unsupported_image_type = "Tipo di immagine non supportato";
$no_products_with_such_code = "nessun prodotto con tale codice";

////////////////////////////////////////////////////////////
// add and update order state
////////////////////////////////////////////////////////////

$empty_order_state_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$order_state_name_too_long = "Il nome dello stato dell'ordine &egrave; troppo lungo: " . $SESSION["order_state_name_length"] . " caratteri max";
$order_state_description_too_long = "La descrizione dello stato dell'ordine &egrave; troppo lunga: " . $SESSION["order_state_description_length"] . " caratteri max";

?>

==> pgmarket-1.5.3.tar.gz: pgmarket-1.5.3/locale/it/global-error.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$Errors = "Errori";

////////////////////////////////////////////////////////////
// Top level scripts
////////////////////////////////////////////////////////////

$login_failed = "Login fallito, riprova";

////////////////////////////////////////////////////////////
// signup, contact us
////////////////////////////////////////////////////////////

$the_username = "La Username";
$already_exists = " &egrave; gi&agrave; in uso";

$empty_username = "Non &egrave; stata specificata la Username";
$username_too_long = "Username troppo lunga: " . $SESSION["username_length"] . " caratteri max";
$username_too_short = "Username troppo corta: " . $SESSION["username_length_min"] . " caratteri min";
$not_valid_username = "Username non valida: usare solo caratteri alfanumerici";

$passwords_do_not_match = "Le password fornite non coincidono";
$empty_password = "Non &egrave; stata specificata la Password";
$please_enable_javascript =
"<b>
Per motivi di sicurezza, per poter acquistare nel nostro negozio virtuale
&egrave; necessario usare JavaScript.
<p>
Il linguaggio JavaScript, oltre a offrire funzionalit&agrave;
molto utili nella realizzazione di software per il Web,
permette di criptare le password e, quindi, di offrire molta sicurezza
in pi&ugrave; a chi fa uso di questo negozio virtuale.
<p>
Perci&ograve; per acquistare nel nostro negozio virtuale &egrave; necessario
un navigatore che supporti JavaScript, come ad esempio Mozilla, Netscape o Explorer.
Se si sta usando un navigatore che supporta JavaScript ma tale supporto
&egrave; stato disabilitato, si prega di modificare le impostazioni
in modo da abilitare JavaScript.
<p>
Nota: le impostazioni di default di Mozilla, Netscape ed Explorer
prevedono l'uso di JavaScript.
</b><br><br>";

$empty_firstname = "Non &egrave; stato specificato il Nome";
$firstname_too_long = "Nome troppo lungo: " . $SESSION["firstname_length"] . " caratteri max";

$empty_ragionesociale = "Non &egrave; stata specificata la Ragione Sociale";
$ragionesociale_too_long = "Ragione Sociale troppo lunga: " . $SESSION["firstname_length"] . " caratteri max";

$empty_lastname = "Non &egrave; stato specificato il Cognome";
$lastname_too_long = "Cognome troppo lungo: " . $SESSION["lastname_length"] . " caratteri max";

$empty_name = "Non &egrave; stato specificato il Nome";
$name_too_long = "Nome troppo lungo: " . $SESSION["name_length"] . " caratteri max";

$empty_fiscalcode = "Non &egrave; stato specificato il Codice Fiscale";
$bad_fiscalcode_length = "Il Codice Fiscale deve contenere " . $SESSION["fiscalcode_length"] . " caratteri alfanumerici";
$not_valid_fiscalcode = "Codice Fiscale non valido";

$empty_partitaiva = "Non &egrave; stata specificata la Partita IVA";
$bad_partitaiva_length = "La Partita IVA deve contenere " . $SESSION["partitaiva_length"] . " cifre";
$not_valid_partitaiva = "Partita IVA non valida";

$empty_address = "Non &egrave; stato specificato l'indirizzo";
$address_too_long = "Via/Piazza troppo lunga: " . $SESSION["address_length"] . " caratteri max";

$number_too_long = "Numero troppo lungo: " . $SESSION["number_length"] . " caratteri max";

$empty_city = "Non &egrave; stato specificato il comune";
$city_too_long = "Comune troppo lungo: " . $SESSION["city_length"] . " caratteri max";

$empty_country = "Non &egrave; stata specificata la citt&agrave;";
$country_too_long = "Citt&agrave; troppo lunga: " . $SESSION["country_length"] . " caratteri max";

$empty_zip_code = "Riempire il campo del CAP";
$zip_code_is_zero = "Il CAP deve essere maggiore di zero";
$zip_code_notint = "Il campo del CAP deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$zip_code_too_long = "CAP troppo lungo: " . $SESSION["zip_code_length"] . " caratteri max";
//$zip_code_length_is_wrong = "Il CAP deve contenere esattamente " . $SESSION["zip_code_length"] . " cifre";
$zip_code_length_is_wrong = "Il CAP deve contenere un numero di cifre pari a ";

$empty_phone = "Non &egrave; stato specificato il numero di telefono";
$phone_too_long = "Numero di telefono troppo lungo: " . $SESSION["phone_length"] . " caratteri max";
$phone_too_short = "Numero di telefono troppo corto: " . $SESSION["phone_length_min"] . " caratteri min";
$not_valid_phone = "Numero di telefono non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$fax_too_long = "Numero di fax troppo lungo: " . $SESSION["fax_length"] . " caratteri max";
$fax_too_short = "Numero di fax troppo corto: " . $SESSION["fax_length_min"] . " caratteri min";
$not_valid_fax = "Numero di fax non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$mobilephone_too_long = "Numero di cellulare troppo lungo: " . $SESSION["mobilephone_length"] . " caratteri max";
$mobilephone_too_short = "Numero di cellulare troppo corto: " . $SESSION["mobilephone_length_min"] . " caratteri min";
$not_valid_mobilephone = "Numero di cellulare non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";

$empty_email = "Non &egrave; stato specificato l'indirizzo e-mail";
$email_too_long = "Indirizzo e-mail troppo lungo: " . $SESSION["email_length"] . " caratteri max";
$not_valid_email = "Indirizzo E-mail non valido";
//$the_email_address = "L'indirizzo E-mail";
//$email_not_on_file = "L'indirizzo E-mail specificato non ci risulta noto";

$notes_too_long = "Annotazioni troppo lunghe: " . $SESSION["notes_length"] . " caratteri max";
$ournotes_too_long = "Annotazioni troppo lunghe nel campo \"" . $Our_Notes . "\": " . $SESSION["ournotes_length"] . " caratteri max";
$empty_message = "Non &egrave; stato scritto nessun Messaggio";
$message_too_long = "Messaggio troppo lungo: " . $SESSION["message_length"] . " caratteri max";

////////////////////////////////////////////////////////////
// purchase now
////////////////////////////////////////////////////////////

$empty_customer = "Non &egrave; stato specificato il Cliente";
$appoggio = $SESSION["firstname_length"] + $SESSION["lastname_length"] + 1;
$customer_too_long = "Campo Cliente troppo lungo: " . $appoggio . " caratteri max";
$empty_contact = "Non &egrave; stato specificato un recapito telefonico";
$contact_too_long = "Recapito telefonico troppo lungo: " . $SESSION["phone_length"] . " caratteri max";
$contact_too_short = "Recapito telefonico troppo corto: " . $SESSION["phone_length_min"] . " caratteri min";
$not_valid_contact = "Recapito telefonico non valido; sono ammessi solo spazi, cifre e i seguenti caratteri: +-()/";
$comments_too_long = "Commenti troppo lunghi: " . $SESSION["comments_length"] . " caratteri max";

////////////////////////////////////////////////////////////
// change password
////////////////////////////////////////////////////////////

$no_old_password = "Non &egrave; stata specificata la vecchia password";
$old_password_not_valid = "La vecchia password &egrave; sbagliata";
$no_new_password = "Non &egrave; stata specificata la nuova password";
$no_new_password2 = "Non &egrave; stata confermata la nuova password";
$new_passwords_dont_match = "Le nuove password non coincidono";

////////////////////////////////////////////////////////////
// languages
////////////////////////////////////////////////////////////

$the_lang = "La lingua ";
$empty_lang = "Non &egrave; stata scelta una lingua; sceglierne una";
$lang_too_long = "L'identificativo scelto per la lingua &egrave; troppo lungo: " . $SESSION["lang_length"] . " caratteri max";
$not_valid_lang = "L'identificativo scelto per la lingua contiene caratteri non validi; sono ammessi solo spazi, cifre e i seguenti caratteri: @._";

////////////////////////////////////////////////////////////
// add and update category
////////////////////////////////////////////////////////////

$empty_category_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$category_name_too_long = "Il nome della categoria &egrave; troppo lungo: " . $SESSION["category_name_length"] . " caratteri max";
$category_description_too_long = "La descrizione della categoria &egrave; troppo lunga: " . $SESSION["category_description_length"] . " caratteri max";

$priv_too_long = "Privilegio troppo lungo: " . $SESSION["priv_length"] . " caratteri max";
$not_valid_priv = "Privilegio non valido: usare solo caratteri alfanumerici";

$Err_ImpCat = ": la Categoria Padre non esiste - '";
$Err_ImpCat_i18n = ": la Categoria non esiste - '";

////////////////////////////////////////////////////////////
// add and update brand
////////////////////////////////////////////////////////////

$empty_brand_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$brand_name_too_long = "Il nome della marca &egrave; troppo lungo: " . $SESSION["brand_name_length"] . " caratteri max";
$brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: " . $SESSION["brand_description_length"] . " caratteri max";

$Err_ImpBrand = ": La Marca non esiste - '";
$Err_ImpIVA = ": La " . $IVA . " non esiste - '";

////////////////////////////////////////////////////////////
// add and update product
////////////////////////////////////////////////////////////

$product_code_is_empty = "Riempire il campo del Codice del prodotto";
$product_code_wspace = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene almeno uno spazio. Si prega di non usare spazi nei Codici dei prodotti.";
$product_code_wampersand = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene il carattere \"&amp;\". Si prega di non usarlo nei Codici dei prodotti.";
$product_code_wquestionm = "Il Codice <b>" . ov($HTTP_POST_VARS["product_code"]) . "</b> contiene il carattere \"?\". Si prega di non usarlo nei Codici dei prodotti.";
$product_code_too_long = "Il Codice del prodotto &egrave; troppo lungo: " . $SESSION["product_code_length"] . " caratteri max";
$the_product_code = "Il Codice ";

$empty_product_name = "Riempire il campo del Nome del prodotto";
$product_name_too_long = "Il nome del prodotto &egrave; troppo lungo: " . $SESSION["product_name_length"] . " caratteri max";

$empty_price = "Riempire il campo del prezzo";
$price_is_zero = "Il Prezzo deve essere maggiore di zero";
$price_notint = "Il campo del Prezzo deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$price_notfloat = "Il campo del Prezzo deve contenere un numero decimale, quindi solo cifre e al pi&ugrave; un punto decimale, nessun altro carattere";

$not_valid_iva = "Valore della " . $IVA . " non valido";
$iva_not_between_0_and_100 = "La " . $IVA . " non &egrave; compresa tra 0 e 100";

$discount_not_completely_defined = "Se si vuole fare sconti sul prodotto, bisogna riempire sia il campo \"" . $Discount . "\" che il campo \"" . $Starting_from . "\"; se non si vuole fare sconti sul prodotto, lasciare vuoti entrambi i campi";
$not_valid_discount = "Sconto non valido";
$discount_not_between_0_and_100 = "Lo Sconto non &egrave; compreso tra 0 e 100";
$discqty_notint = "Il campo \"" . $Starting_from . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
$discqty_is_negative = "Il campo \"" . $Starting_from . "\" non pu&ograve; essere un numero negativo";
$discqty_is_too_large = "Il campo \"" . $Starting_from . "\" &egrave; troppo grande: " . $SESSION["discqtymax"] . " max";

$empty_weight = "Riempire il campo del Peso";
$not_valid_weight = "Peso non valido";
$weight_is_zero = "Il Peso deve essere maggiore di zero";
$weight_over_max = "Peso eccessivo: " . $SESSION["weightmax"] . " " . $weightunity . " max";

$special_level_empty = "Riempire il campo \"" . $Special_Level . "\"";
$special_level_notint = "Il campo \"" . $Special_Level . "\" deve contenere un numero intero, quindi solo cifre, nessun altro carattere";

$product_description_too_long = "La descrizione del prodotto &egrave; troppo lunga: " . $SESSION["product_description_length"] . " caratteri max";
$product_extended_description_too_long = "La descrizione estesa del prodotto &egrave; troppo lunga: " . $SESSION["product_extended_description_length"] . " caratteri max";

$appoggio = floor ($SESSION["max_file_size_images"] / 1024);
$no_product_image_chosen = "Non &egrave; stata scelta una nuova immagine per rappresentare il prodotto, oppure l'immagine scelta &egrave; troppo grande: " . $appoggio . " bytes max";
$image_upload_failed = "Upload dell'immagine fallito";
$unsupported_image_type = "Tipo di immagine non supportato";
$no_products_with_such_code = "nessun prodotto con tale codice";

$Err_ImpProd_i18n = ": il Prodotto non esiste - '";

////////////////////////////////////////////////////////////
// add and update order state
////////////////////////////////////////////////////////////

$empty_order_state_name = "Il campo del nome &egrave; stato lasciato vuoto, si prega di riempirlo";
$order_state_name_too_long = "Il nome dello stato dell'ordine &egrave; troppo lungo: " . $SESSION["order_state_name_length"] . " caratteri max";
$order_state_description_too_long = "La descrizione dello stato dell'ordine &egrave; troppo lunga: " . $SESSION["order_state_description_length"] . " caratteri max";

?>
